@@ -515,10 +515,10 @@ class TrianglePlot:
         """
 
         if self._g is None:
-            for i in range(0,len(p)-1):
+            for i in range(len(p)-1):
                 self._objects.append(self._triangle_factory.triangle(p[i][0], p[i+1][0], c[i][0]))
         else:
-            for i in range(0,len(p)-1):
+            for i in range(len(p)-1):
                 self._objects.append(self._triangle_factory.smooth_triangle(p[i][0], p[i+1][0], c[i][0],p[i][1], p[i+1][1], c[i][1]))
 
     def extrema(self, list):
